from typing import Any, Mapping, Sequence

QUOTE_SAFE_CHAR: str
QUOTE_SAFE_MAPS: Mapping[str, Mapping[Any, str]]
HEX_TO_CHAR_MAP: Mapping[bytes, bytes]

def quote(string_value: str, safe: str = ...) -> str: ...
def quote_plus(string_value: str, safe: str = ...) -> str: ...
def unquote(string_value: str, strict: bool = ...) -> str: ...
def unquote_plus(string_value: str, strict: bool = ...) -> str: ...
def url_encode(
    attributes_map: Mapping[str, str] | None = ...,
    attributes_list: Sequence[tuple[str, str]] | None = ...,
    plus_encoding: bool = ...,
) -> str: ...
