from typing import Sequence

COEFFICIENT_VALUES: Sequence[int]

def calculate_tax_number_control_value(tax_number: int) -> int: ...
def calculate_id_number_control_value(id_number: int) -> int: ...
def _calculate_control_value(number: int) -> int: ...
