from typing import Any, Mapping

class DataCacheMap:
    data_map: Mapping[str, tuple[Any, float]]

    def __init__(self): ...
    def get(self, name: str, timestamp: float | None = None) -> Any: ...
    def add(self, name: str, data: Any, timestamp: float): ...
    def remove(self, name: str): ...
