from re import Pattern

UNDERSCORE_FIRST_VALUE: str
UNDERSCORE_FIRST_REGEX: Pattern[str]
UNDERSCORE_SECOND_VALUE: str
UNDERSCORE_SECOND_REGEX: Pattern[str]

def xor_string_value(first_string: str, second_string: str) -> str: ...
def to_underscore(string_value: str) -> str: ...
def to_camelcase(string_value: str) -> str: ...
def pluralize(string_value: str) -> str: ...
def capitalize_all(string_value: str) -> str: ...
def join(first_value: str, second_value: str, join_value: str = ...) -> str: ...
