FLOAT_PRECISION: int
DELTA: float

def roundi(value: float, places: int = ..., precise: bool = ...) -> float: ...
def rounds(value: float, places: int = ...) -> float: ...
def roundt(value: float, places: int = ...) -> float: ...
def round_apply(force: bool = ...): ...
def round_unapply(force: bool = ...): ...
def round_is_new() -> bool: ...
def _round_t(value: float, places: int = ...) -> float: ...
def _delta(value: float) -> float: ...
