from typing import Sequence, TypeVar

T = TypeVar("T")

def list_intersect(
    first_list: Sequence[T], second_list: Sequence[T]
) -> Sequence[T]: ...
def list_extend(
    base_list: Sequence[T], extension_list: Sequence[T], copy_base_list: bool = ...
) -> Sequence[T]: ...
def list_exclude(
    base_list: Sequence[T], exclusion_list: Sequence[T], copy_base_list: bool = ...
): ...
def list_no_duplicates(list: Sequence[T]) -> list[T]: ...
