from typing import Any, Mapping, TypeVar

T = TypeVar("T")

def ceil_integer(value: int) -> int: ...
def greatest_common_divisor(p_value: int, q_value: int) -> int: ...
def fast_exponentiation(base: int, exponent: int, modulus: int) -> int: ...
def item_set_total(item_set: Mapping[Any, int]) -> int: ...
def item_set_percentage(item_name: T, item_set: Mapping[T, int]) -> float: ...
